# coding: utf-8

"""
    securityapi

    The security APIs help you detect and block security threats.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from cloudmersive_security_api_client.api_client import ApiClient


class ContentThreatDetectionApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def content_threat_detection_automatic_threat_detection_string(self, value, **kwargs):  # noqa: E501
        """Automatically detect threats in an input string  # noqa: E501

        Auto-detects a wide range of threat types in input string, including Cross-Site Scripting (XSS), SQL Injection (SQLI), XML External Entitites (XXE), Server-side Request Forgeries (SSRF), and JSON Insecure Deserialization (JID).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.content_threat_detection_automatic_threat_detection_string(value, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str value: User-facing text input. (required)
        :return: StringAutomaticThreatDetection
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.content_threat_detection_automatic_threat_detection_string_with_http_info(value, **kwargs)  # noqa: E501
        else:
            (data) = self.content_threat_detection_automatic_threat_detection_string_with_http_info(value, **kwargs)  # noqa: E501
            return data

    def content_threat_detection_automatic_threat_detection_string_with_http_info(self, value, **kwargs):  # noqa: E501
        """Automatically detect threats in an input string  # noqa: E501

        Auto-detects a wide range of threat types in input string, including Cross-Site Scripting (XSS), SQL Injection (SQLI), XML External Entitites (XXE), Server-side Request Forgeries (SSRF), and JSON Insecure Deserialization (JID).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.content_threat_detection_automatic_threat_detection_string_with_http_info(value, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str value: User-facing text input. (required)
        :return: StringAutomaticThreatDetection
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['value']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method content_threat_detection_automatic_threat_detection_string" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'value' is set
        if ('value' not in params or
                params['value'] is None):
            raise ValueError("Missing the required parameter `value` when calling `content_threat_detection_automatic_threat_detection_string`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'value' in params:
            body_params = params['value']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/security/threat-detection/content/automatic/detect/string', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='StringAutomaticThreatDetection',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def content_threat_detection_check_sql_injection_string(self, value, **kwargs):  # noqa: E501
        """Check text input for SQL Injection (SQLI) attacks  # noqa: E501

        Detects SQL Injection (SQLI) attacks from text input.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.content_threat_detection_check_sql_injection_string(value, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str value: User-facing text input. (required)
        :return: StringSqlInjectionDetectionResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.content_threat_detection_check_sql_injection_string_with_http_info(value, **kwargs)  # noqa: E501
        else:
            (data) = self.content_threat_detection_check_sql_injection_string_with_http_info(value, **kwargs)  # noqa: E501
            return data

    def content_threat_detection_check_sql_injection_string_with_http_info(self, value, **kwargs):  # noqa: E501
        """Check text input for SQL Injection (SQLI) attacks  # noqa: E501

        Detects SQL Injection (SQLI) attacks from text input.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.content_threat_detection_check_sql_injection_string_with_http_info(value, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str value: User-facing text input. (required)
        :return: StringSqlInjectionDetectionResult
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['value']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method content_threat_detection_check_sql_injection_string" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'value' is set
        if ('value' not in params or
                params['value'] is None):
            raise ValueError("Missing the required parameter `value` when calling `content_threat_detection_check_sql_injection_string`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'value' in params:
            body_params = params['value']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/security/threat-detection/content/sql-injection/detect/string', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='StringSqlInjectionDetectionResult',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def content_threat_detection_check_xxe(self, value, **kwargs):  # noqa: E501
        """Protect text input from XML External Entity (XXE) attacks  # noqa: E501

        Detects XXE (XML External Entity) attacks from XML text input.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.content_threat_detection_check_xxe(value, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str value: User-facing text input. (required)
        :return: StringXxeDetectionResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.content_threat_detection_check_xxe_with_http_info(value, **kwargs)  # noqa: E501
        else:
            (data) = self.content_threat_detection_check_xxe_with_http_info(value, **kwargs)  # noqa: E501
            return data

    def content_threat_detection_check_xxe_with_http_info(self, value, **kwargs):  # noqa: E501
        """Protect text input from XML External Entity (XXE) attacks  # noqa: E501

        Detects XXE (XML External Entity) attacks from XML text input.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.content_threat_detection_check_xxe_with_http_info(value, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str value: User-facing text input. (required)
        :return: StringXxeDetectionResult
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['value']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method content_threat_detection_check_xxe" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'value' is set
        if ('value' not in params or
                params['value'] is None):
            raise ValueError("Missing the required parameter `value` when calling `content_threat_detection_check_xxe`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'value' in params:
            body_params = params['value']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/security/threat-detection/content/xxe/detect/xml/string', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='StringXxeDetectionResult',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def content_threat_detection_detect_insecure_deserialization_json_string(self, value, **kwargs):  # noqa: E501
        """Detect Insecure Deserialization JSON (JID) attacks in a string  # noqa: E501

        Detects Insecure Deserialization JSON (JID) attacks from text input.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.content_threat_detection_detect_insecure_deserialization_json_string(value, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str value: User-facing text input. (required)
        :return: StringInsecureDeserializationJsonDetection
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.content_threat_detection_detect_insecure_deserialization_json_string_with_http_info(value, **kwargs)  # noqa: E501
        else:
            (data) = self.content_threat_detection_detect_insecure_deserialization_json_string_with_http_info(value, **kwargs)  # noqa: E501
            return data

    def content_threat_detection_detect_insecure_deserialization_json_string_with_http_info(self, value, **kwargs):  # noqa: E501
        """Detect Insecure Deserialization JSON (JID) attacks in a string  # noqa: E501

        Detects Insecure Deserialization JSON (JID) attacks from text input.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.content_threat_detection_detect_insecure_deserialization_json_string_with_http_info(value, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str value: User-facing text input. (required)
        :return: StringInsecureDeserializationJsonDetection
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['value']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method content_threat_detection_detect_insecure_deserialization_json_string" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'value' is set
        if ('value' not in params or
                params['value'] is None):
            raise ValueError("Missing the required parameter `value` when calling `content_threat_detection_detect_insecure_deserialization_json_string`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'value' in params:
            body_params = params['value']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/security/threat-detection/content/insecure-deserialization/json/detect/string', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='StringInsecureDeserializationJsonDetection',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def content_threat_detection_protect_xss(self, value, **kwargs):  # noqa: E501
        """Protect text input from Cross-Site-Scripting (XSS) attacks through normalization  # noqa: E501

        Detects and removes XSS (Cross-Site-Scripting) attacks from text input through normalization.  Returns the normalized result, as well as information on whether the original input contained an XSS risk.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.content_threat_detection_protect_xss(value, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str value: User-facing text input. (required)
        :return: StringXssProtectionResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.content_threat_detection_protect_xss_with_http_info(value, **kwargs)  # noqa: E501
        else:
            (data) = self.content_threat_detection_protect_xss_with_http_info(value, **kwargs)  # noqa: E501
            return data

    def content_threat_detection_protect_xss_with_http_info(self, value, **kwargs):  # noqa: E501
        """Protect text input from Cross-Site-Scripting (XSS) attacks through normalization  # noqa: E501

        Detects and removes XSS (Cross-Site-Scripting) attacks from text input through normalization.  Returns the normalized result, as well as information on whether the original input contained an XSS risk.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.content_threat_detection_protect_xss_with_http_info(value, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str value: User-facing text input. (required)
        :return: StringXssProtectionResult
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['value']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method content_threat_detection_protect_xss" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'value' is set
        if ('value' not in params or
                params['value'] is None):
            raise ValueError("Missing the required parameter `value` when calling `content_threat_detection_protect_xss`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'value' in params:
            body_params = params['value']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/security/threat-detection/content/xss/detect/string', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='StringXssProtectionResult',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    securityapi

    The security APIs help you detect and block security threats.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class UrlSsrfThreatDetectionResponseFull(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'clean_url': 'bool',
        'threat_level': 'str'
    }

    attribute_map = {
        'clean_url': 'CleanURL',
        'threat_level': 'ThreatLevel'
    }

    def __init__(self, clean_url=None, threat_level=None):  # noqa: E501
        """UrlSsrfThreatDetectionResponseFull - a model defined in Swagger"""  # noqa: E501

        self._clean_url = None
        self._threat_level = None
        self.discriminator = None

        if clean_url is not None:
            self.clean_url = clean_url
        if threat_level is not None:
            self.threat_level = threat_level

    @property
    def clean_url(self):
        """Gets the clean_url of this UrlSsrfThreatDetectionResponseFull.  # noqa: E501

        True if the URL is clean, false if it is at risk of containing an SSRF threat or attack  # noqa: E501

        :return: The clean_url of this UrlSsrfThreatDetectionResponseFull.  # noqa: E501
        :rtype: bool
        """
        return self._clean_url

    @clean_url.setter
    def clean_url(self, clean_url):
        """Sets the clean_url of this UrlSsrfThreatDetectionResponseFull.

        True if the URL is clean, false if it is at risk of containing an SSRF threat or attack  # noqa: E501

        :param clean_url: The clean_url of this UrlSsrfThreatDetectionResponseFull.  # noqa: E501
        :type: bool
        """

        self._clean_url = clean_url

    @property
    def threat_level(self):
        """Gets the threat_level of this UrlSsrfThreatDetectionResponseFull.  # noqa: E501

        Threat level of the URL; possible values are High, Medium, Low and None  # noqa: E501

        :return: The threat_level of this UrlSsrfThreatDetectionResponseFull.  # noqa: E501
        :rtype: str
        """
        return self._threat_level

    @threat_level.setter
    def threat_level(self, threat_level):
        """Sets the threat_level of this UrlSsrfThreatDetectionResponseFull.

        Threat level of the URL; possible values are High, Medium, Low and None  # noqa: E501

        :param threat_level: The threat_level of this UrlSsrfThreatDetectionResponseFull.  # noqa: E501
        :type: str
        """

        self._threat_level = threat_level

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UrlSsrfThreatDetectionResponseFull, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UrlSsrfThreatDetectionResponseFull):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    securityapi

    The security APIs help you detect and block security threats.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from cloudmersive_security_api_client.api_client import ApiClient


class NetworkThreatDetectionApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def network_threat_detection_detect_ssrf_url(self, request, **kwargs):  # noqa: E501
        """Check a URL for Server-side Request Forgery (SSRF) threats  # noqa: E501

        Checks if an input URL is at risk of being an SSRF (Server-side request forgery) threat or attack.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.network_threat_detection_detect_ssrf_url(request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UrlSsrfThreatDetectionRequestFull request: Input URL request (required)
        :return: UrlSsrfThreatDetectionResponseFull
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.network_threat_detection_detect_ssrf_url_with_http_info(request, **kwargs)  # noqa: E501
        else:
            (data) = self.network_threat_detection_detect_ssrf_url_with_http_info(request, **kwargs)  # noqa: E501
            return data

    def network_threat_detection_detect_ssrf_url_with_http_info(self, request, **kwargs):  # noqa: E501
        """Check a URL for Server-side Request Forgery (SSRF) threats  # noqa: E501

        Checks if an input URL is at risk of being an SSRF (Server-side request forgery) threat or attack.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.network_threat_detection_detect_ssrf_url_with_http_info(request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UrlSsrfThreatDetectionRequestFull request: Input URL request (required)
        :return: UrlSsrfThreatDetectionResponseFull
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method network_threat_detection_detect_ssrf_url" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'request' is set
        if ('request' not in params or
                params['request'] is None):
            raise ValueError("Missing the required parameter `request` when calling `network_threat_detection_detect_ssrf_url`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'request' in params:
            body_params = params['request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/security/threat-detection/network/url/ssrf/detect', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UrlSsrfThreatDetectionResponseFull',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def network_threat_detection_is_bot(self, value, **kwargs):  # noqa: E501
        """Check if IP address is a Bot client threat  # noqa: E501

        Check if the input IP address is a Bot, robot, or otherwise a non-user entity.  Leverages real-time signals to check against known high-probability bots..  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.network_threat_detection_is_bot(value, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str value: IP address to check, e.g. \"55.55.55.55\".  The input is a string so be sure to enclose it in double-quotes. (required)
        :return: ThreatDetectionBotCheckResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.network_threat_detection_is_bot_with_http_info(value, **kwargs)  # noqa: E501
        else:
            (data) = self.network_threat_detection_is_bot_with_http_info(value, **kwargs)  # noqa: E501
            return data

    def network_threat_detection_is_bot_with_http_info(self, value, **kwargs):  # noqa: E501
        """Check if IP address is a Bot client threat  # noqa: E501

        Check if the input IP address is a Bot, robot, or otherwise a non-user entity.  Leverages real-time signals to check against known high-probability bots..  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.network_threat_detection_is_bot_with_http_info(value, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str value: IP address to check, e.g. \"55.55.55.55\".  The input is a string so be sure to enclose it in double-quotes. (required)
        :return: ThreatDetectionBotCheckResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['value']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method network_threat_detection_is_bot" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'value' is set
        if ('value' not in params or
                params['value'] is None):
            raise ValueError("Missing the required parameter `value` when calling `network_threat_detection_is_bot`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'value' in params:
            body_params = params['value']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/security/threat-detection/network/ip/is-bot', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ThreatDetectionBotCheckResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def network_threat_detection_is_threat(self, value, **kwargs):  # noqa: E501
        """Check if IP address is a known threat  # noqa: E501

        Check if the input IP address is a known threat IP address.  Checks against known bad IPs, botnets, compromised servers, and other lists of threats.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.network_threat_detection_is_threat(value, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str value: IP address to check, e.g. \"55.55.55.55\".  The input is a string so be sure to enclose it in double-quotes. (required)
        :return: IPThreatDetectionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.network_threat_detection_is_threat_with_http_info(value, **kwargs)  # noqa: E501
        else:
            (data) = self.network_threat_detection_is_threat_with_http_info(value, **kwargs)  # noqa: E501
            return data

    def network_threat_detection_is_threat_with_http_info(self, value, **kwargs):  # noqa: E501
        """Check if IP address is a known threat  # noqa: E501

        Check if the input IP address is a known threat IP address.  Checks against known bad IPs, botnets, compromised servers, and other lists of threats.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.network_threat_detection_is_threat_with_http_info(value, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str value: IP address to check, e.g. \"55.55.55.55\".  The input is a string so be sure to enclose it in double-quotes. (required)
        :return: IPThreatDetectionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['value']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method network_threat_detection_is_threat" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'value' is set
        if ('value' not in params or
                params['value'] is None):
            raise ValueError("Missing the required parameter `value` when calling `network_threat_detection_is_threat`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'value' in params:
            body_params = params['value']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/security/threat-detection/network/ip/is-threat', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='IPThreatDetectionResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def network_threat_detection_is_tor_node(self, value, **kwargs):  # noqa: E501
        """Check if IP address is a Tor node server  # noqa: E501

        Check if the input IP address is a Tor exit node server.  Tor servers are a type of privacy-preserving technology that can hide the original IP address who makes a request.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.network_threat_detection_is_tor_node(value, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str value: IP address to check, e.g. \"55.55.55.55\".  The input is a string so be sure to enclose it in double-quotes. (required)
        :return: ThreatDetectionTorNodeResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.network_threat_detection_is_tor_node_with_http_info(value, **kwargs)  # noqa: E501
        else:
            (data) = self.network_threat_detection_is_tor_node_with_http_info(value, **kwargs)  # noqa: E501
            return data

    def network_threat_detection_is_tor_node_with_http_info(self, value, **kwargs):  # noqa: E501
        """Check if IP address is a Tor node server  # noqa: E501

        Check if the input IP address is a Tor exit node server.  Tor servers are a type of privacy-preserving technology that can hide the original IP address who makes a request.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.network_threat_detection_is_tor_node_with_http_info(value, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str value: IP address to check, e.g. \"55.55.55.55\".  The input is a string so be sure to enclose it in double-quotes. (required)
        :return: ThreatDetectionTorNodeResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['value']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method network_threat_detection_is_tor_node" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'value' is set
        if ('value' not in params or
                params['value'] is None):
            raise ValueError("Missing the required parameter `value` when calling `network_threat_detection_is_tor_node`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'value' in params:
            body_params = params['value']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/security/threat-detection/network/ip/is-tor-node', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ThreatDetectionTorNodeResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    securityapi

    The security APIs help you detect and block security threats.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import cloudmersive_security_api_client
from cloudmersive_security_api_client.models.string_automatic_threat_detection import StringAutomaticThreatDetection  # noqa: E501
from cloudmersive_security_api_client.rest import ApiException


class TestStringAutomaticThreatDetection(unittest.TestCase):
    """StringAutomaticThreatDetection unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testStringAutomaticThreatDetection(self):
        """Test StringAutomaticThreatDetection"""
        # FIXME: construct object with mandatory attributes with example values
        # model = cloudmersive_security_api_client.models.string_automatic_threat_detection.StringAutomaticThreatDetection()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    securityapi

    The security APIs help you detect and block security threats.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import cloudmersive_security_api_client
from cloudmersive_security_api_client.api.content_threat_detection_api import ContentThreatDetectionApi  # noqa: E501
from cloudmersive_security_api_client.rest import ApiException


class TestContentThreatDetectionApi(unittest.TestCase):
    """ContentThreatDetectionApi unit test stubs"""

    def setUp(self):
        self.api = cloudmersive_security_api_client.api.content_threat_detection_api.ContentThreatDetectionApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_content_threat_detection_automatic_threat_detection_string(self):
        """Test case for content_threat_detection_automatic_threat_detection_string

        Automatically detect threats in an input string  # noqa: E501
        """
        pass

    def test_content_threat_detection_check_sql_injection_string(self):
        """Test case for content_threat_detection_check_sql_injection_string

        Check text input for SQL Injection (SQLI) attacks  # noqa: E501
        """
        pass

    def test_content_threat_detection_check_xxe(self):
        """Test case for content_threat_detection_check_xxe

        Protect text input from XML External Entity (XXE) attacks  # noqa: E501
        """
        pass

    def test_content_threat_detection_detect_insecure_deserialization_json_string(self):
        """Test case for content_threat_detection_detect_insecure_deserialization_json_string

        Detect Insecure Deserialization JSON (JID) attacks in a string  # noqa: E501
        """
        pass

    def test_content_threat_detection_protect_xss(self):
        """Test case for content_threat_detection_protect_xss

        Protect text input from Cross-Site-Scripting (XSS) attacks through normalization  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    securityapi

    The security APIs help you detect and block security threats.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import cloudmersive_security_api_client
from cloudmersive_security_api_client.api.network_threat_detection_api import NetworkThreatDetectionApi  # noqa: E501
from cloudmersive_security_api_client.rest import ApiException


class TestNetworkThreatDetectionApi(unittest.TestCase):
    """NetworkThreatDetectionApi unit test stubs"""

    def setUp(self):
        self.api = cloudmersive_security_api_client.api.network_threat_detection_api.NetworkThreatDetectionApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_network_threat_detection_detect_ssrf_url(self):
        """Test case for network_threat_detection_detect_ssrf_url

        Check a URL for Server-side Request Forgery (SSRF) threats  # noqa: E501
        """
        pass

    def test_network_threat_detection_is_bot(self):
        """Test case for network_threat_detection_is_bot

        Check if IP address is a Bot client threat  # noqa: E501
        """
        pass

    def test_network_threat_detection_is_threat(self):
        """Test case for network_threat_detection_is_threat

        Check if IP address is a known threat  # noqa: E501
        """
        pass

    def test_network_threat_detection_is_tor_node(self):
        """Test case for network_threat_detection_is_tor_node

        Check if IP address is a Tor node server  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from cloudmersive_security_api_client.api.content_threat_detection_api import ContentThreatDetectionApi
from cloudmersive_security_api_client.api.network_threat_detection_api import NetworkThreatDetectionApi



# coding: utf-8

# flake8: noqa

"""
    securityapi

    The security APIs help you detect and block security threats.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import apis into sdk package
from cloudmersive_security_api_client.api.content_threat_detection_api import ContentThreatDetectionApi
from cloudmersive_security_api_client.api.network_threat_detection_api import NetworkThreatDetectionApi

# import ApiClient
from cloudmersive_security_api_client.api_client import ApiClient
from cloudmersive_security_api_client.configuration import Configuration
# import models into sdk package
from cloudmersive_security_api_client.models.ip_threat_detection_response import IPThreatDetectionResponse
from cloudmersive_security_api_client.models.string_automatic_threat_detection import StringAutomaticThreatDetection
from cloudmersive_security_api_client.models.string_insecure_deserialization_json_detection import StringInsecureDeserializationJsonDetection
from cloudmersive_security_api_client.models.string_sql_injection_detection_result import StringSqlInjectionDetectionResult
from cloudmersive_security_api_client.models.string_xss_protection_result import StringXssProtectionResult
from cloudmersive_security_api_client.models.string_xxe_detection_result import StringXxeDetectionResult
from cloudmersive_security_api_client.models.threat_detection_bot_check_response import ThreatDetectionBotCheckResponse
from cloudmersive_security_api_client.models.threat_detection_tor_node_response import ThreatDetectionTorNodeResponse
from cloudmersive_security_api_client.models.url_ssrf_threat_detection_request_full import UrlSsrfThreatDetectionRequestFull
from cloudmersive_security_api_client.models.url_ssrf_threat_detection_response_full import UrlSsrfThreatDetectionResponseFull



# coding: utf-8

"""
    securityapi

    The security APIs help you detect and block security threats.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class StringAutomaticThreatDetection(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'successful': 'bool',
        'clean_result': 'bool',
        'contained_json_insecure_deserialization_attack': 'bool',
        'contained_xss_threat': 'bool',
        'contained_xxe_threat': 'bool',
        'contained_sql_injection_threat': 'bool',
        'contained_ssrf_threat': 'bool',
        'is_xml': 'bool',
        'is_json': 'bool',
        'is_url': 'bool',
        'original_input': 'str'
    }

    attribute_map = {
        'successful': 'Successful',
        'clean_result': 'CleanResult',
        'contained_json_insecure_deserialization_attack': 'ContainedJsonInsecureDeserializationAttack',
        'contained_xss_threat': 'ContainedXssThreat',
        'contained_xxe_threat': 'ContainedXxeThreat',
        'contained_sql_injection_threat': 'ContainedSqlInjectionThreat',
        'contained_ssrf_threat': 'ContainedSsrfThreat',
        'is_xml': 'IsXML',
        'is_json': 'IsJSON',
        'is_url': 'IsURL',
        'original_input': 'OriginalInput'
    }

    def __init__(self, successful=None, clean_result=None, contained_json_insecure_deserialization_attack=None, contained_xss_threat=None, contained_xxe_threat=None, contained_sql_injection_threat=None, contained_ssrf_threat=None, is_xml=None, is_json=None, is_url=None, original_input=None):  # noqa: E501
        """StringAutomaticThreatDetection - a model defined in Swagger"""  # noqa: E501

        self._successful = None
        self._clean_result = None
        self._contained_json_insecure_deserialization_attack = None
        self._contained_xss_threat = None
        self._contained_xxe_threat = None
        self._contained_sql_injection_threat = None
        self._contained_ssrf_threat = None
        self._is_xml = None
        self._is_json = None
        self._is_url = None
        self._original_input = None
        self.discriminator = None

        if successful is not None:
            self.successful = successful
        if clean_result is not None:
            self.clean_result = clean_result
        if contained_json_insecure_deserialization_attack is not None:
            self.contained_json_insecure_deserialization_attack = contained_json_insecure_deserialization_attack
        if contained_xss_threat is not None:
            self.contained_xss_threat = contained_xss_threat
        if contained_xxe_threat is not None:
            self.contained_xxe_threat = contained_xxe_threat
        if contained_sql_injection_threat is not None:
            self.contained_sql_injection_threat = contained_sql_injection_threat
        if contained_ssrf_threat is not None:
            self.contained_ssrf_threat = contained_ssrf_threat
        if is_xml is not None:
            self.is_xml = is_xml
        if is_json is not None:
            self.is_json = is_json
        if is_url is not None:
            self.is_url = is_url
        if original_input is not None:
            self.original_input = original_input

    @property
    def successful(self):
        """Gets the successful of this StringAutomaticThreatDetection.  # noqa: E501

        True if the operation was successful, false otherwise  # noqa: E501

        :return: The successful of this StringAutomaticThreatDetection.  # noqa: E501
        :rtype: bool
        """
        return self._successful

    @successful.setter
    def successful(self, successful):
        """Sets the successful of this StringAutomaticThreatDetection.

        True if the operation was successful, false otherwise  # noqa: E501

        :param successful: The successful of this StringAutomaticThreatDetection.  # noqa: E501
        :type: bool
        """

        self._successful = successful

    @property
    def clean_result(self):
        """Gets the clean_result of this StringAutomaticThreatDetection.  # noqa: E501


        :return: The clean_result of this StringAutomaticThreatDetection.  # noqa: E501
        :rtype: bool
        """
        return self._clean_result

    @clean_result.setter
    def clean_result(self, clean_result):
        """Sets the clean_result of this StringAutomaticThreatDetection.


        :param clean_result: The clean_result of this StringAutomaticThreatDetection.  # noqa: E501
        :type: bool
        """

        self._clean_result = clean_result

    @property
    def contained_json_insecure_deserialization_attack(self):
        """Gets the contained_json_insecure_deserialization_attack of this StringAutomaticThreatDetection.  # noqa: E501

        True if the input contained Insecure Deserialization JSON, false otherwise  # noqa: E501

        :return: The contained_json_insecure_deserialization_attack of this StringAutomaticThreatDetection.  # noqa: E501
        :rtype: bool
        """
        return self._contained_json_insecure_deserialization_attack

    @contained_json_insecure_deserialization_attack.setter
    def contained_json_insecure_deserialization_attack(self, contained_json_insecure_deserialization_attack):
        """Sets the contained_json_insecure_deserialization_attack of this StringAutomaticThreatDetection.

        True if the input contained Insecure Deserialization JSON, false otherwise  # noqa: E501

        :param contained_json_insecure_deserialization_attack: The contained_json_insecure_deserialization_attack of this StringAutomaticThreatDetection.  # noqa: E501
        :type: bool
        """

        self._contained_json_insecure_deserialization_attack = contained_json_insecure_deserialization_attack

    @property
    def contained_xss_threat(self):
        """Gets the contained_xss_threat of this StringAutomaticThreatDetection.  # noqa: E501

        True if the input contained XSS attack, false otherwise  # noqa: E501

        :return: The contained_xss_threat of this StringAutomaticThreatDetection.  # noqa: E501
        :rtype: bool
        """
        return self._contained_xss_threat

    @contained_xss_threat.setter
    def contained_xss_threat(self, contained_xss_threat):
        """Sets the contained_xss_threat of this StringAutomaticThreatDetection.

        True if the input contained XSS attack, false otherwise  # noqa: E501

        :param contained_xss_threat: The contained_xss_threat of this StringAutomaticThreatDetection.  # noqa: E501
        :type: bool
        """

        self._contained_xss_threat = contained_xss_threat

    @property
    def contained_xxe_threat(self):
        """Gets the contained_xxe_threat of this StringAutomaticThreatDetection.  # noqa: E501

        True if the input contained XXE attack, false otherwise  # noqa: E501

        :return: The contained_xxe_threat of this StringAutomaticThreatDetection.  # noqa: E501
        :rtype: bool
        """
        return self._contained_xxe_threat

    @contained_xxe_threat.setter
    def contained_xxe_threat(self, contained_xxe_threat):
        """Sets the contained_xxe_threat of this StringAutomaticThreatDetection.

        True if the input contained XXE attack, false otherwise  # noqa: E501

        :param contained_xxe_threat: The contained_xxe_threat of this StringAutomaticThreatDetection.  # noqa: E501
        :type: bool
        """

        self._contained_xxe_threat = contained_xxe_threat

    @property
    def contained_sql_injection_threat(self):
        """Gets the contained_sql_injection_threat of this StringAutomaticThreatDetection.  # noqa: E501

        True if the input contained SQL Injection attack, false otherwise  # noqa: E501

        :return: The contained_sql_injection_threat of this StringAutomaticThreatDetection.  # noqa: E501
        :rtype: bool
        """
        return self._contained_sql_injection_threat

    @contained_sql_injection_threat.setter
    def contained_sql_injection_threat(self, contained_sql_injection_threat):
        """Sets the contained_sql_injection_threat of this StringAutomaticThreatDetection.

        True if the input contained SQL Injection attack, false otherwise  # noqa: E501

        :param contained_sql_injection_threat: The contained_sql_injection_threat of this StringAutomaticThreatDetection.  # noqa: E501
        :type: bool
        """

        self._contained_sql_injection_threat = contained_sql_injection_threat

    @property
    def contained_ssrf_threat(self):
        """Gets the contained_ssrf_threat of this StringAutomaticThreatDetection.  # noqa: E501

        True if the input contained an Server-Side Request Forgery (SSRF) URL attack, false otherwise  # noqa: E501

        :return: The contained_ssrf_threat of this StringAutomaticThreatDetection.  # noqa: E501
        :rtype: bool
        """
        return self._contained_ssrf_threat

    @contained_ssrf_threat.setter
    def contained_ssrf_threat(self, contained_ssrf_threat):
        """Sets the contained_ssrf_threat of this StringAutomaticThreatDetection.

        True if the input contained an Server-Side Request Forgery (SSRF) URL attack, false otherwise  # noqa: E501

        :param contained_ssrf_threat: The contained_ssrf_threat of this StringAutomaticThreatDetection.  # noqa: E501
        :type: bool
        """

        self._contained_ssrf_threat = contained_ssrf_threat

    @property
    def is_xml(self):
        """Gets the is_xml of this StringAutomaticThreatDetection.  # noqa: E501

        True if the input string is XML, false otherwise  # noqa: E501

        :return: The is_xml of this StringAutomaticThreatDetection.  # noqa: E501
        :rtype: bool
        """
        return self._is_xml

    @is_xml.setter
    def is_xml(self, is_xml):
        """Sets the is_xml of this StringAutomaticThreatDetection.

        True if the input string is XML, false otherwise  # noqa: E501

        :param is_xml: The is_xml of this StringAutomaticThreatDetection.  # noqa: E501
        :type: bool
        """

        self._is_xml = is_xml

    @property
    def is_json(self):
        """Gets the is_json of this StringAutomaticThreatDetection.  # noqa: E501

        True if the input string is JSON, false otherwise  # noqa: E501

        :return: The is_json of this StringAutomaticThreatDetection.  # noqa: E501
        :rtype: bool
        """
        return self._is_json

    @is_json.setter
    def is_json(self, is_json):
        """Sets the is_json of this StringAutomaticThreatDetection.

        True if the input string is JSON, false otherwise  # noqa: E501

        :param is_json: The is_json of this StringAutomaticThreatDetection.  # noqa: E501
        :type: bool
        """

        self._is_json = is_json

    @property
    def is_url(self):
        """Gets the is_url of this StringAutomaticThreatDetection.  # noqa: E501

        True if the input string is a URL, false otherwise  # noqa: E501

        :return: The is_url of this StringAutomaticThreatDetection.  # noqa: E501
        :rtype: bool
        """
        return self._is_url

    @is_url.setter
    def is_url(self, is_url):
        """Sets the is_url of this StringAutomaticThreatDetection.

        True if the input string is a URL, false otherwise  # noqa: E501

        :param is_url: The is_url of this StringAutomaticThreatDetection.  # noqa: E501
        :type: bool
        """

        self._is_url = is_url

    @property
    def original_input(self):
        """Gets the original_input of this StringAutomaticThreatDetection.  # noqa: E501

        Original input string  # noqa: E501

        :return: The original_input of this StringAutomaticThreatDetection.  # noqa: E501
        :rtype: str
        """
        return self._original_input

    @original_input.setter
    def original_input(self, original_input):
        """Sets the original_input of this StringAutomaticThreatDetection.

        Original input string  # noqa: E501

        :param original_input: The original_input of this StringAutomaticThreatDetection.  # noqa: E501
        :type: str
        """

        self._original_input = original_input

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(StringAutomaticThreatDetection, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StringAutomaticThreatDetection):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    securityapi

    

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from setuptools import setup, find_packages  # noqa: H301

NAME = "cloudmersive_security_api_client"
VERSION = "3.0.1"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
from os import path
this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

REQUIRES = [
    "certifi>=2017.4.17",
    "python-dateutil>=2.1",
    "six>=1.10",
    "urllib3>=1.23"
]
    

setup(
    name=NAME,
    version=VERSION,
    description="securityapi",
    author_email="",
    url="https://www.cloudmersive.com/security-threat-detection-api",
    keywords=["Swagger", "securityapi"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description=long_description,
    long_description_content_type='text/markdown'
    

)
